@@ -33,14 +33,12 @@ from datetime import datetime, timedelta
 import warnings
 from requests.utils import quote
 
-from ._logging import get_logger, logged_api_call
+from ._logging import logged_api_call
 from ._exceptions import NotFound, NoUniqueMatch, HTTPError
 from ._utils import repr_list
 
 __all__ = ['BaseManager']
 
-LOG = get_logger(__name__)
-
 
 class _NameUriCache(object):
     """
@@ -264,17 +262,17 @@ class BaseManager(object):
         """
         ret = (
             "{classname} at 0x{id:08x} (\n"
-            "  _resource_class = {_resource_class!r}\n"
-            "  _class_name = {_class_name!r}\n"
-            "  _session = {_session_classname} at 0x{_session_id:08x}\n"
-            "  _parent = {_parent_classname} at 0x{_parent_id:08x}\n"
-            "  _base_uri = {_base_uri!r}\n"
-            "  _oid_prop = {_oid_prop!r}\n"
-            "  _uri_prop = {_uri_prop!r}\n"
-            "  _name_prop = {_name_prop!r}\n"
-            "  _query_props = {_query_props}\n"
-            "  _list_has_name = {_list_has_name!r}\n"
-            "  _name_uri_cache = {_name_uri_cache!r}\n"
+            "  _resource_class={_resource_class!r},\n"
+            "  _class_name={_class_name!r},\n"
+            "  _session={_session_classname} at 0x{_session_id:08x},\n"
+            "  _parent={_parent_classname} at 0x{_parent_id:08x},\n"
+            "  _base_uri={_base_uri!r},\n"
+            "  _oid_prop={_oid_prop!r},\n"
+            "  _uri_prop={_uri_prop!r},\n"
+            "  _name_prop={_name_prop!r},\n"
+            "  _query_props={_query_props},\n"
+            "  _list_has_name={_list_has_name!r},\n"
+            "  _name_uri_cache={_name_uri_cache!r}\n"
             ")".format(
                 classname=self.__class__.__name__,
                 id=id(self),
