@@ -41,12 +41,10 @@ from ._exceptions import StatusTimeout
 from ._nic import NicManager
 from ._hba import HbaManager
 from ._virtual_function import VirtualFunctionManager
-from ._logging import get_logger, logged_api_call
+from ._logging import logged_api_call
 
 __all__ = ['PartitionManager', 'Partition']
 
-LOG = get_logger(__name__)
-
 
 class PartitionManager(BaseManager):
     """
@@ -1050,6 +1048,47 @@ class Partition(BaseResource):
         self.manager.session.post(
             self.uri + '/operations/change-crypto-domain-configuration', body)
 
+    @logged_api_call
+    def zeroize_crypto_domain(self, crypto_adapter, crypto_domain_index):
+        """
+        Zeroize a single crypto domain on a crypto adapter.
+
+        Zeroizing a crypto domain clears the cryptographic keys and
+        non-compliance mode settings in the crypto domain.
+
+        The crypto domain must be attached to this partition in "control-usage"
+        access mode.
+
+        Supported CPC versions: z14 GA2 and above, and the corresponding
+        LinuxOne systems.
+
+        Authorization requirements:
+
+        * Object-access permission to this Partition and to the Crypto Adapter.
+        * Task permission to the "Zeroize Crypto Domain" task.
+
+        Parameters:
+
+          crypto_adapter (:class:`~zhmcclient.Adapter`):
+            Crypto adapter with the crypto domain to be zeroized.
+
+          crypto_domain_index (:term:`integer`):
+            Domain index of the crypto domain to be zeroized.
+
+        Raises:
+
+          :exc:`~zhmcclient.HTTPError`
+          :exc:`~zhmcclient.ParseError`
+          :exc:`~zhmcclient.AuthError`
+          :exc:`~zhmcclient.ConnectionError`
+        """
+        body = {
+            'crypto-adapter-uri': crypto_adapter.uri,
+            'domain-index': crypto_domain_index
+        }
+        self.manager.session.post(
+            self.uri + '/operations/zeroize-crypto-domain', body)
+
     @logged_api_call
     def attach_storage_group(self, storage_group):
         """
@@ -1163,9 +1202,9 @@ class Partition(BaseResource):
         sg_list = []
         sg_uris = self.get_property('storage-group-uris')
         if sg_uris:
-            cpc = self.manager.cpc
+            console = self.manager.cpc.manager.console
             for sg_uri in sg_uris:
-                sg = cpc.storage_groups.resource_object(sg_uri)
+                sg = console.storage_groups.resource_object(sg_uri)
                 sg_list.append(sg)
                 if full_properties:
                     sg.pull_full_properties()
