@@ -26,12 +26,10 @@ import copy
 
 from ._manager import BaseManager
 from ._resource import BaseResource
-from ._logging import get_logger, logged_api_call
+from ._logging import logged_api_call
 
 __all__ = ['PortManager', 'Port']
 
-LOG = get_logger(__name__)
-
 
 class PortManager(BaseManager):
     """
