@@ -18,6 +18,7 @@ Session class: A session to the HMC, optionally in context of an HMC user.
 
 from __future__ import absolute_import
 
+import sys
 import json
 import time
 import re
@@ -45,9 +46,7 @@ from ._constants import DEFAULT_CONNECT_TIMEOUT, DEFAULT_CONNECT_RETRIES, \
 
 __all__ = ['Session', 'Job', 'RetryTimeoutConfig', 'get_password_interface']
 
-LOG = get_logger(__name__)
-
-HMC_LOG = get_logger(HMC_LOGGER_NAME)
+HMC_LOGGER = get_logger(HMC_LOGGER_NAME)
 
 _HMC_SCHEME = "https"
 _STD_HEADERS = {
@@ -55,6 +54,8 @@ _STD_HEADERS = {
     'Accept': '*/*'
 }
 
+BLANKED_OUT = '********'  # Replacement for blanked out sensitive values
+
 
 def _handle_request_exc(exc, retry_timeout_config):
     """
@@ -232,6 +233,20 @@ def get_password_interface(host, userid):
     raise NotImplementedError
 
 
+def _headers_for_logging(headers):
+    """
+    Return the input headers dict with blanked out values for any headers that
+    carry sensitive information, so that it can be logged or displayed.
+
+    The headers argument is not modified; if it needs to be changed, a copy is
+    made that is changed.
+    """
+    if headers and 'X-API-Session' in headers:
+        headers = headers.copy()
+        headers['X-API-Session'] = BLANKED_OUT
+    return headers
+
+
 class Session(object):
     """
     A session to the HMC, optionally in context of an HMC user.
@@ -364,18 +379,21 @@ class Session(object):
         """
         Return a string with the state of this session, for debug purposes.
         """
+        headers = _headers_for_logging(self.headers)
         ret = (
             "{classname} at 0x{id:08x} (\n"
-            "  _host = {s._host!r}\n"
-            "  _userid = {s._userid!r}\n"
-            "  _password = '...'\n"
-            "  _get_password = {s._get_password!r}\n"
-            "  _retry_timeout_config = {s._retry_timeout_config!r}\n"
-            "  _base_url = {s._base_url!r}\n"
-            "  _headers = {s._headers!r}\n"
-            "  _session_id = {s._session_id!r}\n"
-            "  _session = {s._session!r}\n"
-            ")".format(classname=self.__class__.__name__, id=id(self), s=self))
+            "  _host={s._host!r},\n"
+            "  _userid={s._userid!r},\n"
+            "  _password='...',\n"
+            "  _get_password={s._get_password!r},\n"
+            "  _retry_timeout_config={s._retry_timeout_config!r},\n"
+            "  _base_url={s._base_url!r},\n"
+            "  _headers={headers!r},\n"
+            "  _session_id={blanked_out!r},\n"
+            "  _session={s._session!r}\n"
+            ")".
+            format(classname=self.__class__.__name__, id=id(self), s=self,
+                   headers=headers, blanked_out=BLANKED_OUT))
         return ret
 
     @property
@@ -647,12 +665,18 @@ class Session(object):
             request
         """
         if method == 'POST' and url.endswith('/api/sessions'):
+            # In Python 3 up to 3.5, json.loads() requires unicode strings.
+            if sys.version_info[0] == 3 and sys.version_info[1] in (4, 5) and \
+                    isinstance(content, six.binary_type):
+                content = content.decode('utf-8')
+            # Because zhmcclient has built the request, we are not handling
+            # any JSON parse errors from json.loads().
             content_dict = json.loads(content)
-            content_dict['password'] = '********'
-            content = json.dumps(content)
-        HMC_LOG.debug("HMC request: %s %s, headers: %r, "
-                      "content(max.1000): %.1000r",
-                      method, url, headers, content)
+            content_dict['password'] = BLANKED_OUT
+            content = json.dumps(content_dict)
+        HMC_LOGGER.debug("Request: %s %s, headers: %r, "
+                         "content(max.1000): %.1000r",
+                         method, url, _headers_for_logging(headers), content)
 
     @staticmethod
     def _log_http_response(method, url, status, headers=None, content=None):
@@ -672,9 +696,24 @@ class Session(object):
           content (:term:`string`): HTTP body (aka content) returned in the
             response
         """
-        HMC_LOG.debug("HMC response: %s %s, status: %s, headers: %r, "
-                      "content(max.1000): %.1000r",
-                      method, url, status, headers, content)
+        if method == 'POST' and url.endswith('/api/sessions'):
+            # In Python 3 up to 3.5, json.loads() requires unicode strings.
+            if sys.version_info[0] == 3 and sys.version_info[1] in (4, 5) and \
+                    isinstance(content, six.binary_type):
+                content = content.decode('utf-8')
+            try:
+                content_dict = json.loads(content)
+            except ValueError as exc:
+                content = '"Error: Cannot parse JSON payload of response: ' \
+                    '{}"'.format(exc)
+            else:
+                content_dict['api-session'] = BLANKED_OUT
+                content_dict['session-credential'] = BLANKED_OUT
+                content = json.dumps(content_dict)
+        HMC_LOGGER.debug("Respons: %s %s, status: %s, headers: %r, "
+                         "content(max.1000): %.1000r",
+                         method, url, status, _headers_for_logging(headers),
+                         content)
 
     @logged_api_call
     def get(self, uri, logon_required=True):
@@ -741,6 +780,10 @@ class Session(object):
                 # API session token expired: re-logon and retry
                 self._do_logon()
                 return self.get(uri, logon_required)
+            elif reason == 1:
+                # Login user's authentication is fine; this is an authorization
+                # issue, so we don't raise ServerAuthError.
+                raise HTTPError(result_object)
             else:
                 msg = result_object.get('message', None)
                 raise ServerAuthError("HTTP authentication failed: {}".
@@ -941,6 +984,10 @@ class Session(object):
                     # API session token expired: re-logon and retry
                     self._do_logon()
                     return self.post(uri, body, logon_required)
+                elif reason == 1:
+                    # Login user's authentication is fine; this is an
+                    # authorization issue, so we don't raise ServerAuthError.
+                    raise HTTPError(result_object)
                 else:
                     msg = result_object.get('message', None)
                     raise ServerAuthError("HTTP authentication failed: {}".
@@ -1017,6 +1064,10 @@ class Session(object):
                 self._do_logon()
                 self.delete(uri, logon_required)
                 return
+            elif reason == 1:
+                # Login user's authentication is fine; this is an authorization
+                # issue, so we don't raise ServerAuthError.
+                raise HTTPError(result_object)
             else:
                 msg = result_object.get('message', None)
                 raise ServerAuthError("HTTP authentication failed: {}".
