@@ -44,12 +44,10 @@ import copy
 
 from ._manager import BaseManager
 from ._resource import BaseResource
-from ._logging import get_logger, logged_api_call
+from ._logging import logged_api_call
 
 __all__ = ['StorageVolumeManager', 'StorageVolume']
 
-LOG = get_logger(__name__)
-
 
 class StorageVolumeManager(BaseManager):
     """
